# How to DDD

---

This Guide will have a series of general tips on how to effectively apply your DPS to frigates, along with a detailed breakdown of each site.

## General Tips

- DDD is best done with a 3 or 4 web Vindicator.
- You should have 4 damage mods and follow the website fit.
- Splitting guns 4-4 is best when you have good skills.
- Your effective range is roughly between 6km and your heated web range.
- Make sure your speed is as close to 0m/s as possible to maximise tracking when shooting.
- If you are burning or if the frigates aren't webbed, it is still worthwhile to shoot and hope for a lucky shot.
- Use Void if targets are close, use Null if targets are further away.
- Heating webs is incredibly important & effective as it gives them an extra few kilometers of range.
- Train up Minmatar and Gallente Battleship skills. Aim for Minmatar Battleship 4 at a minimum.
- Abyssal webs are strongly recommended. Try to aim for 15km range at 60% strength.
- You will need to learn your anchor positioning yourself but ask if unsure.
- Drop booster gives you a tracking bonus and is pretty much mandatory to be effective.
- Always run Pyrolancea to give yourself extra DPS.

Try to sit still as much as possible, hitting frigates with large guns is not easy and requires you to be webbing targets and keeping your transversal velocity as low as possible (you can add transversal to your overview in the columns section). Burning around with your MWD on will result in continually missed hits and no dead frigates. Ship placement during waves will help you significantly, so be in position before wave spawns, if aggro switches move to a place where you can be effective!

There is a priority order to frigates, but remember to always shoot the frigates closest to optimal, and with the lowest transversal, you will kill them much faster this way so keep checking your overview, and memorise your optimal ranges with each ammo type.

You may have light drones as support but they are NOT your main source of damage, so make sure to keep shooting. Splitting your gun groupings can be beneficial to kill multiple frigates at once and helps to keep drones shooting. If you are struggling for damage however keep your guns grouped together.

If the frigate spawn is pulled away from you switch to Null! Do not be idle, you can still kill frigates with Null. If frigates are out of web range, overheat your webs, it costs very little in paste to repair webs so make good use of it. Use both groups of guns to kill single targets if needed. You are not a marauder, you are free to burn to do your job whenever it is neccesary.

The meatshield or MS is usually tagged with the letter Z, use this to aid you in finding where to anchor during waves as the meatshield often acts as initial aggro for most sites & waves and you want to be nearby to this ship. This is where all the sansha frigates will be going.

## Contests

Your role doesnt really change in contests, so shoot frigates as best as you can. The waves will die really fast so make sure you burn straight to your anchors and do as much DPS as you can. During TCRC contests you should be focused on shooting the tower with the rest of the fleet and locking up Niarjas incase they jam any of our marauders, if they do you need to kill them ASAP.

## Site Breakdowns

### TPPH

- 1st room burn forward one or two propmod cycles, prioritise Schmaeels, then Tama. At the beginning of the room have Null loaded to try to kill one or two as they burn in close, switch to Void and work through remaining frigates.
- 2nd room burn forward or MJD if the aggro target jumps depending on your preffered fit. Kill the four frigates as fast as you can and prioritise the Schmaeels first.
- 3rd room burn directly to your anchor, you want to be between the 2nd wave spawn and the MS, but on the closer side to the MS. When the 2nd wave spawns and the MS pulls aggro you should be well within web range of the frigates. Start with Schmaeels first then on to Tamas. From here on its a case of working through all the frigates, the wave will almost always be pushed meaning more frigates will spawn on the final wave. If you are shooting frigates when the final wave spawns you are very likely to get aggro so broadcast for CAP if you got neuted so that you can continue to do your job of webbing frigates. Marauders will help you clean up at this point.

### NRF

- 1st wave you want to burn in two propmod cycles towards the wave. Depending on the size of the spawn you may need to start anchoring before the wave dies, the switch will usually happen about a minute after entering the site and the frigates will change their target and try to burn away, this is your best time to hit them if you have them webbed. Be in position for next wave!
- 2nd, 3rd & 4th wave your anchor will be above the MS and between them and the wave spawns, this way the frigates should come to you. Start with Schmaeels, then onto Tamas. Remember to burn in to the 4th wave to help shoot everything else once frigates are dead. Webbing Romi's can help alot.

### TCRC

- Niarjas are your TOP priority in this site, this is because they jam & neut, they will also respawn. When you land on the beacon sit still, using null, quickly kill the closest Niarja. While this is happening spread your webs for nearby Schmaeels but dont bother with the tag X's. Try to kill off as many Schmaeels as you can before the aggro switchs. When aggro switches the remaining Schmaeels will burn toward the tower so align and MJD to the left of it or burn depending on your fit. When you are anchored kill the remaining Niarja & between Niarja respawns kill off untagged Schmaeels. Remember the Niarja is priority number one so kill it the moment it respawns. When there are no untagged Schmaeels left web the x's and help shoot the tower. The X tag Schmaeels will respawn after a set amount of time if killed, but they will never respawn once the tower is dead, so when the tower is around 20% structure you can kill off the remaining X tags so that the fleet can make quick work of the Auga and exit site promptly.
